summaryrefslogtreecommitdiff
path: root/src/irc/proxy/proxy.c
diff options
context:
space:
mode:
authordequis <dx@dxzone.com.ar>2015-06-14 11:57:11 -0300
committerdequis <dx@dxzone.com.ar>2015-06-14 11:57:11 -0300
commita47f45b5b7438209177d76f3efde559e61e5bdb7 (patch)
tree8b84024a6eb7629a8b99206e35d6f45b79cf4c13 /src/irc/proxy/proxy.c
parent29fb0d98023de26e643b213177ecb9fbb73d83f8 (diff)
downloadirssi-a47f45b5b7438209177d76f3efde559e61e5bdb7.zip
Rename /proxy command to /irssiproxy for clarity
Diffstat (limited to 'src/irc/proxy/proxy.c')
-rw-r--r--src/irc/proxy/proxy.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/irc/proxy/proxy.c b/src/irc/proxy/proxy.c
index 65c778d1..ce79e2b7 100644
--- a/src/irc/proxy/proxy.c
+++ b/src/irc/proxy/proxy.c
@@ -25,8 +25,8 @@
#include "fe-common/core/printtext.h"
-/* SYNTAX: PROXY STATUS */
-static void cmd_proxy_status(const char *data, IRC_SERVER_REC *server)
+/* SYNTAX: IRSSIPROXY STATUS */
+static void cmd_irssiproxy_status(const char *data, IRC_SERVER_REC *server)
{
if (!settings_get_bool("irssiproxy")) {
printtext(server, NULL, MSGLEVEL_CLIENTNOTICE,
@@ -51,15 +51,15 @@ static void cmd_proxy_status(const char *data, IRC_SERVER_REC *server)
}
}
-/* SYNTAX: PROXY */
-static void cmd_proxy(const char *data, IRC_SERVER_REC *server, void *item)
+/* SYNTAX: IRSSIPROXY */
+static void cmd_irssiproxy(const char *data, IRC_SERVER_REC *server, void *item)
{
if (*data == '\0') {
- cmd_proxy_status(data, server);
+ cmd_irssiproxy_status(data, server);
return;
}
- command_runsub("proxy", data, server, item);
+ command_runsub("irssiproxy", data, server, item);
}
static void irc_proxy_setup_changed(void)
@@ -92,8 +92,8 @@ void irc_proxy_init(void)
"... to set them.");
}
- command_bind("proxy", NULL, (SIGNAL_FUNC) cmd_proxy);
- command_bind("proxy status", NULL, (SIGNAL_FUNC) cmd_proxy_status);
+ command_bind("irssiproxy", NULL, (SIGNAL_FUNC) cmd_irssiproxy);
+ command_bind("irssiproxy status", NULL, (SIGNAL_FUNC) cmd_irssiproxy_status);
signal_add_first("setup changed", (SIGNAL_FUNC) irc_proxy_setup_changed);